// UVa : 10167.

// Algo : trier les cerises par angle croissant (en fait on manipule
// la tangente des angles). On part d'une droite verticale et on va la
// faire tourner dans le sens trigo. On fait tourner la droite jusqu'a
// la prochaine cerise. Puis on calcule une droite tres proche,
// orientee du bon cote (sens trigo toujours), dont on est sur qu'elle
// n'intersecte aucune cerise (cf apres). On verifie si cette droite
// convient. Sinon on continue de tourner.

// Pour trouver une droite qui n'intersecte aucune cerise, on peut
// faire ca avec Bezout et Euclide. En effet, pour deux cerises (x,y)
// et (x',y'), on a |x/y-x'/y'| >= 1/(100|y|) et aussi |y/x-y'/x'| >=
// 1/(100|x|). Donc il suffit de trouver un point (u,v) a coordonnees
// <= 500 verifiant xu+yv=1 et max(|u|,|v|) > 100 : ainsi, |x/y-u/v| <
// 1/(100|y|) ou |y/x-v/u| < 1/(100|x|), et c'est gagne. Il faut juste
// faire attention aux orientations.

// Note : ne passe pas le juge PC !?

#include <stdlib.h>
#include <iostream>
#include <math.h>

#define N 102 // nb max de cerises
#define K 450

struct cerise
{
  int x, y;
};


int comparaison(const void* a1, const void* a2)
{
  int x1 = ((cerise *) a1)->x;
  int y1 = ((cerise *) a1)->y;
  int x2 = ((cerise *) a2)->x;
  int y2 = ((cerise *) a2)->y;
  return x1*x2*(x2*y1-x1*y2);
}

int signe(int a)
{
  if (a>=0)
    return 1;
  return -1;
}

int euclide (int x, int y, int *u, int *v) {
  int q, r, s, t, tmp, a, b;
  
  a=abs(x); b=abs(y);
  *u = 1;
  *v = 0;
  s = 0;
  t = 1;
  while (b > 0) {
    q = a / b;
    r = a % b;
    a = b;
    b = r;
    tmp = s;
    s = *u - q * s;
    *u = tmp;
    tmp = t;
    t = *v - q * t;
    *v = tmp;
  }

  // grossir u ou v pour qu'il soit plus grand que 100 en valeur absolue

  int lambda ;
  if (abs(x) > abs(y))
    {
      lambda = (200*signe(x*y)+*v)/abs(x);
      *u += lambda*abs(y);
      *v -= lambda*abs(x);
    }
  else
    {
      lambda = (200*signe(x*y)-*u)/abs(y);
      *u += lambda*abs(y);
      *v -= lambda*abs(x);
    }
  return a;
}

int main()
{
  int bidon1, bidon2;
  int a, b;

  int n;

  cerise cerises[N];
  int nb_xzero_ypos;
  int nb_xzero_yneg;
  int x, y;
  int difference;

  std::cin >> n;

  while (n != 0)
    {
      int j=0, k=0;
      nb_xzero_ypos = 0;
      nb_xzero_yneg = 0;
      for (int i=0; i<2*n; ++i)
	{
	  std::cin >> x >> y;
	  if (x == 0)
	    {
	      if (y > 0)
		++nb_xzero_ypos;
	      else
		++nb_xzero_yneg;
	    }
	  else
	    {
	      cerises[j].x = x;
	      cerises[j].y = y;
	      if (x>0)
		{
		  ++j;
		}
	      else
		{
		  ++j;
		  ++k;
		}
	    }
	}
      difference = nb_xzero_ypos-nb_xzero_yneg+j-2*k;
      if (difference == 0)
	{
	  if (nb_xzero_ypos == 0 && nb_xzero_yneg == 0)
	    std::cout << "1 0\n";
	  else
	    std::cout << K << " 1\n";
	  std::cin >> n;
	  continue;
	}
      qsort(cerises, j, sizeof(cerise), comparaison);
      int l=0;
      while (l < j && difference != 0)
	{
	  x = cerises[l].x;
	  y = cerises[l].y;
	  while (l < j && x*cerises[l].y == cerises[l].x*y)
	    {
	      if (cerises[l].x > 0)
		difference -= 2;
	      else
		difference += 2;
	      ++l;
	    }
	}
      // dernier point lu : (x, y)
      if (y == 0)
	{
	  std::cout << "-1 " << K << std::endl;
	  std::cin >> n;
	  continue;
	}
      a = -y/euclide(x,y,&bidon1,&bidon2);
      b = x/euclide(x,y,&bidon1,&bidon2);
      // trouver une droite proche qui ne passe par aucune cerise
      euclide(a, b, &x, &y);
      x *= signe(a*b);
      // equation de la droite : (-y, x)
      std::cout << -y << ' ' << x << std::endl;
      std::cin >> n;
    }
}
